@@ -1,52 +1,50 @@
-from cherrypy.test import test
-test.prefer_parent_path()
-
 import sys
 
 import cherrypy
 from cherrypy.test import helper
 
 
-def setup_server():
-    
-    conf = cherrypy.config.copy()
-    
-    def load_tut_module(name):
-        """Import or reload tutorial module as needed."""
-        cherrypy.config.reset()
-        cherrypy.config.update(conf)
-        
-        target = "cherrypy.tutorial." + name
-        if target in sys.modules:
-            module = reload(sys.modules[target])
-        else:
-            module = __import__(target, globals(), locals(), [''])
-        # The above import will probably mount a new app at "".
-        app = cherrypy.tree.apps[""]
-        
-        app.root.load_tut_module = load_tut_module
-        app.root.sessions = sessions
-        app.root.traceback_setting = traceback_setting
-        
-        helper.sync_apps()
-    load_tut_module.exposed = True
-    
-    def sessions():
-        cherrypy.config.update({"tools.sessions.on": True})
-    sessions.exposed = True
-    
-    def traceback_setting():
-        return repr(cherrypy.request.show_tracebacks)
-    traceback_setting.exposed = True
-    
-    class Dummy:
-        pass
-    root = Dummy()
-    root.load_tut_module = load_tut_module
-    cherrypy.tree.mount(root)
-
-
 class TutorialTest(helper.CPWebCase):
+
+    def setup_server(cls):
+        
+        conf = cherrypy.config.copy()
+        
+        def load_tut_module(name):
+            """Import or reload tutorial module as needed."""
+            cherrypy.config.reset()
+            cherrypy.config.update(conf)
+            
+            target = "cherrypy.tutorial." + name
+            if target in sys.modules:
+                module = reload(sys.modules[target])
+            else:
+                module = __import__(target, globals(), locals(), [''])
+            # The above import will probably mount a new app at "".
+            app = cherrypy.tree.apps[""]
+            
+            app.root.load_tut_module = load_tut_module
+            app.root.sessions = sessions
+            app.root.traceback_setting = traceback_setting
+            
+            cls.supervisor.sync_apps()
+        load_tut_module.exposed = True
+        
+        def sessions():
+            cherrypy.config.update({"tools.sessions.on": True})
+        sessions.exposed = True
+        
+        def traceback_setting():
+            return repr(cherrypy.request.show_tracebacks)
+        traceback_setting.exposed = True
+        
+        class Dummy:
+            pass
+        root = Dummy()
+        root.load_tut_module = load_tut_module
+        cherrypy.tree.mount(root)
+    setup_server = classmethod(setup_server)
+
     
     def test01HelloWorld(self):
         self.getPage("/load_tut_module/tut01_helloworld")
@@ -117,6 +115,7 @@ class TutorialTest(helper.CPWebCase):
         self.getPage('/hendrik')
         self.assertBody('Hendrik Mans, CherryPy co-developer & crazy German '
                         '(<a href="./">back</a>)')
+    
     def test07Sessions(self):
         self.getPage("/load_tut_module/tut07_sessions")
         self.getPage("/sessions")
@@ -143,23 +142,23 @@ class TutorialTest(helper.CPWebCase):
         self.getPage("/load_tut_module/tut09_files")
         
         # Test upload
+        filesize = 5
         h = [("Content-type", "multipart/form-data; boundary=x"),
-             ("Content-Length", "110")]
-        b = """--x
-Content-Disposition: form-data; name="myFile"; filename="hello.txt"
-Content-Type: text/plain
-
-hello
---x--
-"""
+             ("Content-Length", str(105 + filesize))]
+        b = '--x\n' + \
+            'Content-Disposition: form-data; name="myFile"; filename="hello.txt"\r\n' + \
+            'Content-Type: text/plain\r\n' + \
+            '\r\n' + \
+            'a' * filesize + '\n' + \
+            '--x--\n'
         self.getPage('/upload', h, "POST", b)
         self.assertBody('''<html>
         <body>
-            myFile length: 5<br />
+            myFile length: %d<br />
             myFile filename: hello.txt<br />
             myFile mime-type: text/plain
         </body>
-        </html>''')
+        </html>''' % filesize)
     
         # Test download
         self.getPage('/download')
@@ -200,13 +199,3 @@ hello
         self.assertStatus(500)
         self.assertInBody("If you construct an HTTPError with a 'message'")
 
-
-if __name__ == "__main__":
-    conf = {'server.socket_host': '127.0.0.1',
-            'server.socket_port': 8080,
-            'server.thread_pool': 10,
-            'environment': "test_suite",
-            }
-    cherrypy.config.update(conf)
-    setup_server()
-    helper.testmain()
